@@ -14,8 +14,3 @@ mprint <- function(...) {
   if (!getOption("doFuture.debug", FALSE)) return()
   message(paste(capture.output(print(...)), collapse = "\n"))
 }
-
-import_future <- function(name, mode = "function") {
-  ns <- getNamespace("future")
-  get(name, envir = ns, mode = "function")
-}
