@@ -1,13 +1,13 @@
-findRdTopics <- function(package) {
+find_rd_topics <- function(package) {
   path <- find.package(package)
   file <- file.path(path, "help", "aliases.rds")
   topics <- readRDS(file)
   unique(topics)
-} ## findRdTopics()
+}
 
 
 ## Tweak all plyr functions with argument '.parallel'
-tweakPlyr <- function() {
+tweak_plyr <- function() {
   ns <- getNamespace("plyr")
 
   vars <- ls(envir = ns, all.names = TRUE)
@@ -18,34 +18,41 @@ tweakPlyr <- function() {
     if (!".parallel" %in% names(fmls)) next
     formals(fcn)$.parallel <- TRUE
     message(" - plyr function tweaked: ", var)
-    assignInNamespace(var, fcn, ns=ns)
-  } 
+    assignInNamespace(var, fcn, ns = ns)
+  }
 
   setup_parallel <- getFromNamespace("setup_parallel", ns = ns)
   body(setup_parallel) <- body(setup_parallel)[-3]
   assignInNamespace("setup_parallel", setup_parallel, ns = ns)
-} ## tweakPlyr()
+}
+
+mprintf <- function(...) message(sprintf(...))
 
 
 ## Package for which examples should be run
 pkg <- "plyr"
 
-message(sprintf("*** doFuture() - all %s examples ...", pkg))
+mprintf("*** doFuture() - all %s examples ...", pkg)
 
 library("future")
-options(warnPartialMatchArgs=FALSE)
-oopts <- options(mc.cores=2L, warn=1L, digits=3L)
-strategies <- future:::supportedStrategies()
-strategies <- setdiff(strategies, c("multiprocess", "lazy", "eager"))
-if (require("future.BatchJobs")) strategies <- c(strategies, "batchjobs_local")
-if (require("future.batchtools")) strategies <- c(strategies, "batchtools_local")
-strategies <- getOption("doFuture.tests.strategies", strategies)
+options(warnPartialMatchArgs = FALSE)
+oopts <- options(mc.cores = 2L, warn = 1L, digits = 3L)
+strategies <- getOption("doFuture.tests.strategies")
+strategies <- strsplit(strategies, split = "[, ]")[[1]]
+strategies <- strategies[nzchar(strategies)]
+## Default is to use what's provided by the future package
+if (length(strategies) == 0) {
+  strategies <- future:::supportedStrategies()
+  strategies <- setdiff(strategies, c("multiprocess", "lazy", "eager"))
+}
+if (any(grepl("batchjobs_", strategies))) library("future.BatchJobs")
+if (any(grepl("batchtools_", strategies))) library("future.batchtools")
 
 library("doFuture")
 registerDoFuture()
-library(pkg, character.only=TRUE)
-tweakPlyr()
-topics <- getOption("doFuture.tests.topics", findRdTopics(pkg))
+library(pkg, character.only = TRUE)
+tweak_plyr()
+topics <- getOption("doFuture.tests.topics", find_rd_topics(pkg))
 
 ## Exclude a few tests that takes very long time to run:
 excl <- NULL
@@ -67,28 +74,28 @@ excl <- getOption("doFuture.tests.topics.ignore", NULL)
 topics <- setdiff(topics, excl)
 
 for (strategy in strategies) {
-  message(sprintf("- plan('%s') ...", strategy))
+  mprintf("- plan('%s') ...", strategy)
   plan(strategy)
 
   for (ii in seq_along(topics)) {
     topic <- topics[ii]
-    message(sprintf("- #%d of %d example(%s, package='%s') using plan(%s) ...", ii, length(topics), topic, pkg, strategy))
+    mprintf("- #%d of %d example(%s, package = '%s') using plan(%s) ...", ii, length(topics), topic, pkg, strategy) #nolint
     dt <- NULL
-    ovars <- ls(all.names=TRUE)
+    ovars <- ls(all.names = TRUE)
     dt <- system.time({
-      example(topic, package=pkg, character.only=TRUE, ask=FALSE)
+      example(topic, package = pkg, character.only = TRUE, ask = FALSE)
     })
     graphics.off()
-    rm(list=setdiff(ls(all.names=TRUE), c(ovars, "ovars")))
+    rm(list = setdiff(ls(all.names = TRUE), c(ovars, "ovars")))
     dt <- dt[1:3]; names(dt) <- c("user", "system", "elapsed")
     dt <- paste(sprintf("%s: %g", names(dt), dt), collapse = ", ")
     message("  Total processing time for example: ", dt)
-    message(sprintf("- #%d of %d example(%s, package='%s') using plan(%s) ... DONE (%s)", ii, length(topics), topic, pkg, strategy, dt))
+    mprintf("- #%d of %d example(%s, package = '%s') using plan(%s) ... DONE (%s)", ii, length(topics), topic, pkg, strategy, dt) #nolint
   } ## for (ii ...)
 
-  message(sprintf("- plan('%s') ... DONE", strategy))
+  mprintf("- plan('%s') ... DONE", strategy)
 } ## for (strategy ...)
 
-message(sprintf("*** doFuture() - all %s examples ... DONE", pkg))
+mprintf("*** doFuture() - all %s examples ... DONE", pkg)
 
 options(oopts)
